@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlyFileImporter|
-|''Version''|0.3.4|
+|''Version''|0.3.5|
 |''Author''|Ben Gillies|
 |''Type''|plugin|
 |''Description''|Upload a TiddlyWiki file to TiddlyWeb, and import the tiddlers.|
@@ -58,7 +58,7 @@ config.macros.fileImport = {
 		var iframe = $('<iframe name="' + iframeName + '" '
 			+ 'style="display: none" />').appendTo(uploadWrapper);
 		var onSubmit = function(ev) {
-			var uploadType = $('select', wizard.formElem).val();
+			var uploadType = $('select[name=uploadtype]', wizard.formElem).val();
 			if (uploadType == "file") {
 				// set an onload ready to hijack the form
 				me.setOnLoad(uploadWrapper, wizard, iframe[0]);
@@ -67,8 +67,8 @@ config.macros.fileImport = {
 			} else {
 				var csrf_token = config.extensions.tiddlyspace.getCSRFToken();
 				$.ajax({
-					url: "%0/reflector?csrf_token=%1".format([
-						config.defaultCustomFields["server.host"], csrf_token]),
+					url: "%0/reflector?csrf_token=%1".format(
+						config.defaultCustomFields["server.host"], csrf_token),
 					type: "POST",
 					dataType: "text",
 					data: {
@@ -102,7 +102,7 @@ config.macros.fileImport = {
 		var form = wizard.formElem;
 		var me = config.macros.fileImport;
 		form.action = me.reflectorURI.format(
-			[config.extensions.tiddlyspace.getCSRFToken()]);
+			config.extensions.tiddlyspace.getCSRFToken());
 		form.enctype = 'multipart/form-data';
 		form.method = 'POST';
 		form.target = iframeName;
@@ -110,17 +110,17 @@ config.macros.fileImport = {
 			var changeTo = $(this).val();
 			if (changeTo == "file") {
 				$(".importFrom").html('%0 <input type="file" name="file" />'.
-					format([me.step1FileText]));
+					format(me.step1FileText));
 			} else {
 				$(".importFrom").html('%0 <input type="text" name="uri" />'.
-					format([me.step1URLText]));
+					format(me.step1URLText));
 			}
 		};
-		$(place).append('<span>%0</span>'.format([me.step1TypeChooser])).
-			append($('<select><option value="file" selected="selected">file'
+		$(place).append('<span>%0</span>'.format(me.step1TypeChooser)).
+			append($('<select name="uploadtype"><option value="file" selected="selected">file'
 				+ '<option value="uri">url</select>').change(onSelectChange)).
 			append('<div class="importFrom">%0<input type="file" name="file" />'.
-					format([me.step1FileText])
+					format(me.step1FileText)
 				+ '</div>');
 	},
 
@@ -234,4 +234,4 @@ config.macros.importTiddlers.onGetTiddlerList = function(context, wizard) {
 	_onGetTiddlerList.apply(this, arguments);
 }
 })(jQuery);
-//}}}
+//}}}
\ No newline at end of file
